@@ -1,7 +1,5 @@
-/* $Id: BuzzMachineCallbacks.cpp 3124 2011-01-09 13:25:00Z ensonic $
- *
- * Buzz Machine Loader
- * Copyright (C) 2006 Buzztard team <buzztard-devel@lists.sf.net>
+/* Buzz Machine Loader
+ * Copyright (C) 2006 Buzztrax team <buzztrax-devel@buzztrax.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,9 +12,7 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #define BUZZ_MACHINE_CALLBACKS_CPP
@@ -32,7 +28,6 @@
 #include <stdio.h>
 #include "debug.h"
 
-#include "MachineInterface.h"
 #include "BuzzMachineCallbacks.h"
 //#include "BuzzMDKHelper.h"
 #include "mdkimp.h"
@@ -73,6 +68,10 @@ CWaveLevel const *BuzzMachineCallbacks::GetNearestWaveLevel(int const i, int con
         DBG1("return the mdk helper, %p\n",mdkHelper);
         return((CWaveLevel *)mdkHelper);
     }
+    if((i==-2) && (note==-2)) {
+      // if(pCB->GetHostVersion() >= 2) { newbuzz = 1; }
+      FIXME;
+    }
     
     if(host_callbacks && *host_callbacks) {
         return (CWaveLevel *)(*host_callbacks)->GetNearestWaveLevel(*host_callbacks,i,note);
