@@ -1,7 +1,5 @@
-/* $Id: bmltest_info.c 3724 2011-12-02 17:50:30Z ensonic $
- *
- * Buzz Machine Loader
- * Copyright (C) 2006 Buzztard team <buzztard-devel@lists.sf.net>
+/* Buzz Machine Loader
+ * Copyright (C) 2006 Buzztrax team <buzztrax-devel@buzztrax.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,9 +12,7 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 /**
  * display machine info block
@@ -46,61 +42,59 @@ static inline double
 _get_timestamp (void)
 {
 #ifdef HAVE_CLOCK_GETTIME
-  struct timespec now;
+  struct timespec ts;
 
-  clock_gettime (CLOCK_MONOTONIC, &now);
-  return ((double)now.tv_sec + ((double)now.tv_nsec/1000000000.0));
+  clock_gettime (CLOCK_MONOTONIC, &ts);
+  return ((double)ts.tv_sec + ((double)ts.tv_nsec * 1.0e-9));
 #else
-/*
-  GTimeVal now;
+  struct timeval ts;
+
+  gettimeofday (&ts, NULL);
+  return ((double)ts.tv_sec + ((double)ts.tv_usec * 1.0e-6));
 
-  g_get_current_time (&now);
-  return GST_TIMEVAL_TO_TIME (now);
-*/
-  return 0UL;
 #endif
 }
 
-#ifdef HAVE_X86
+#ifdef USE_DLLWRAPPER
 #define bml(a) bmlw_ ## a
 #include "bmltest_info.h"
 #undef bml
-#endif  /* HAVE_X86 */
+#endif  /* USE_DLLWRAPPER */
 
 #define bml(a) bmln_ ## a
 #include "bmltest_info.h"
 #undef bml
 
 int main( int argc, char **argv ) {
+  int okay=0;
   setlinebuf(stdout);
   setlinebuf(stderr);
   puts("main beg");
 
   if(bml_setup()) {
     char *lib_name;
-    int sl;
-    int i;
+    int sl,i;
 
-#ifdef HAVE_X86
+#ifdef USE_DLLWRAPPER
     /* FIXME: if people have no real win32 dlls, only emulated things, this will crash here */
     bmlw_set_master_info(120,4,44100);
-#endif
+#endif  /* USE_DLLWRAPPER */
     bmln_set_master_info(120,4,44100);
-    puts("  master info initialized");
+    puts("master info initialized");
 
     for(i=1;i<argc;i++) {
       lib_name=argv[i];
       sl=strlen(lib_name);
       if(sl>4) {
-        if(!strcmp(&lib_name[sl-4],".dll")) {
-#ifdef HAVE_X86
-          bmlw_test_info(lib_name);
+        if(!strcasecmp(&lib_name[sl-4],".dll")) {
+#ifdef USE_DLLWRAPPER
+          okay=bmlw_test_info(lib_name);
 #else
           puts("no dll emulation on non x86 platforms");
-#endif  /* HAVE_X86 */
+#endif  /* USE_DLLWRAPPER */
         }
         else {
-          bmln_test_info(lib_name);
+          okay=bmln_test_info(lib_name);
         }
       }
     }
@@ -108,6 +102,6 @@ int main( int argc, char **argv ) {
   }
 
   puts("main end");
-  return 0;
+  return okay ? 0 : 1;
 }
 
