@@ -1,7 +1,5 @@
-/* $Id: bmltest_info.h 3166 2011-01-28 22:51:41Z ensonic $
- *
- * Buzz Machine Loader
- * Copyright (C) 2009 Buzztard team <buzztard-devel@lists.sf.net>
+/* Buzz Machine Loader
+ * Copyright (C) 2009 Buzztrax team <buzztrax-devel@buzztrax.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,20 +12,19 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-void bml(test_info(char *libpath)) {
+int bml(test_info(char *libpath)) {
+  int okay=0;
   // buzz machine handle
   void *bmh,*bm;
   char *str;
-  int type,val,i,num,tracks;
-  int maval,mival,noval,ptrval=0;
+  int type,val,i,num,tracks,numtrig;
+  int maval,mival,noval;
   double ts1, ts2;
 
-  printf("%s(\"%s\")\n",__FUNCTION__,libpath);
+  printf("%s: loading \"%s\"\n",__FUNCTION__,libpath);
 
   ts1=_get_timestamp();
 
@@ -35,7 +32,6 @@ void bml(test_info(char *libpath)) {
     if((bm=bml(new(bmh)))) {
       char *machine_types[]={"MT_MASTER","MT_GENERATOR","MT_EFFECT" };
       char *parameter_types[]={"PT_NOTE","PT_SWITCH","PT_BYTE","PT_WORD" };
-      void *addr;
 
       ts2=_get_timestamp();
       printf("  machine created in %lf sec\n",ts2-ts1);
@@ -74,10 +70,13 @@ void bml(test_info(char *libpath)) {
       tracks=val;
       if(bml(get_machine_info(bmh,BM_PROP_MAX_TRACKS,(void *)&val)))           printf("    MaxTracks: %i\n",val);
       if(bml(get_machine_info(bmh,BM_PROP_NUM_INPUT_CHANNELS,(void *)&val)))   printf("    InputChannels: %d\n",val);
-      if(bml(get_machine_info(bmh,BM_PROP_NUM_OUTPUT_CHANNELS,(void *)&val)))  printf("    OutputChannels: %d\n",val);
-      fflush(stdout);
+      if(bml(get_machine_info(bmh,BM_PROP_NUM_OUTPUT_CHANNELS,(void *)&val)))  printf("    OutputChannels: %d\n",val);fflush(stdout);
       if(bml(get_machine_info(bmh,BM_PROP_NUM_GLOBAL_PARAMS,(void *)&val))) {  printf("    NumGlobalParams: %i\n",val);fflush(stdout);
-        num=val;
+        num=val;numtrig=0;
+        for(i=0;i<num;i++)
+          if(bml(get_global_parameter_info(bmh,i,BM_PARA_FLAGS,(void *)&val)))
+            if(val&&(1<<1)==0) numtrig++;
+        printf("    NumGlobalTriggerParams: %i\n",numtrig);fflush(stdout);
         for(i=0;i<num;i++) {
           printf("      GlobalParam=%02i\n",i);
           if(bml(get_global_parameter_info(bmh,i,BM_PARA_TYPE,(void *)&type)))        printf("        Type: %i -> \"%s\"\n",type,((type<4)?parameter_types[type]:"unknown"));
@@ -92,26 +91,24 @@ void bml(test_info(char *libpath)) {
           if(bml(get_global_parameter_info(bmh,i,BM_PARA_MIN_VALUE,(void *)&mival)) &&
              bml(get_global_parameter_info(bmh,i,BM_PARA_MAX_VALUE,(void *)&maval)) &&
              bml(get_global_parameter_info(bmh,i,BM_PARA_NO_VALUE,(void *)&noval)) &&
-             bml(get_global_parameter_info(bmh,i,BM_PARA_DEF_VALUE,(void *)&val)))    printf("        Value: %d .. %d .. %d [%d]\n",mival,val,maval,noval);
-          val =        bml(get_global_parameter_value(bm,i));
-          addr=        bml(get_global_parameter_location(bm,i));
-          str =(char *)bml(describe_global_value(bmh,i,val));
-          switch(type) {
-            case 0: //PT_NOTE:
-            case 1: //PT_SWITCH:
-            case 2: //PT_BYTE:
-              ptrval=(int)(*(char *)addr);
-              break;
-            case 3: //PT_WORD:
-              ptrval=(int)(*(short *)addr);
-              break;
+             bml(get_global_parameter_info(bmh,i,BM_PARA_DEF_VALUE,(void *)&val))) {
+            printf("        Value: %d .. %d .. %d [%d]\n",mival,val,maval,noval);
+            val =        bml(get_global_parameter_value(bm,i));
+            str =(char *)bml(describe_global_value(bmh,i,val));
+            printf("        RealValue: %d %s (NULL)\n",val,str);
           }
-          printf("        RealValue: %d %s (%p -> %d)\n",val,str,addr,ptrval);
         }
       }
+      else {
+        puts("    NumGlobalTriggerParams: 0");
+      }
       fflush(stdout);
       if(bml(get_machine_info(bmh,BM_PROP_NUM_TRACK_PARAMS,(void *)&val))) {   printf("    NumTrackParams: %i\n",val);fflush(stdout);
-        num=val;
+        num=val;numtrig=0;
+        for(i=0;i<num;i++)
+          if(bml(get_track_parameter_info(bmh,i,BM_PARA_FLAGS,(void *)&val)))
+            if(val&&(1<<1)==0) numtrig++;
+        printf("    NumTrackTriggerParams: %i\n",numtrig);fflush(stdout);
         if(num && tracks) {
           for(i=0;i<num;i++) {
             printf("      TrackParam=%02i\n",i);
@@ -127,21 +124,12 @@ void bml(test_info(char *libpath)) {
             if(bml(get_track_parameter_info(bmh,i,BM_PARA_MIN_VALUE,(void *)&mival)) &&
                bml(get_track_parameter_info(bmh,i,BM_PARA_MAX_VALUE,(void *)&maval)) &&
                bml(get_track_parameter_info(bmh,i,BM_PARA_NO_VALUE,(void *)&noval)) &&
-               bml(get_track_parameter_info(bmh,i,BM_PARA_DEF_VALUE,(void *)&val)))    printf("        Value: %d .. %d .. %d [%d]\n",mival,val,maval,noval);
-            val =        bml(get_track_parameter_value(bm,0,i));
-            addr=        bml(get_track_parameter_location(bm,0,i));
-            str =(char *)bml(describe_track_value(bmh,i,val));
-            switch(type) {
-              case 0: //PT_NOTE:
-              case 1: //PT_SWITCH:
-              case 2: //PT_BYTE:
-                ptrval=(int)(*(char *)addr);
-                break;
-              case 3: //PT_WORD:
-                ptrval=(int)(*(short *)addr);
-                break;
+               bml(get_track_parameter_info(bmh,i,BM_PARA_DEF_VALUE,(void *)&val))) {
+              printf("        Value: %d .. %d .. %d [%d]\n",mival,val,maval,noval);
+              val =        bml(get_track_parameter_value(bm,0,i));
+              str =(char *)bml(describe_track_value(bmh,i,val));
+              printf("        RealValue: %d %s (NULL)\n",val,str);
             }
-            printf("        RealValue: %d %s (%p -> %d)\n",val,str,addr,ptrval);
           }
         }
         else {
@@ -150,6 +138,9 @@ void bml(test_info(char *libpath)) {
           }
         }
       }
+      else {
+        puts("    NumTrackTriggerParams: 0");
+      }
       fflush(stdout);
       if(bml(get_machine_info(bmh,BM_PROP_NUM_ATTRIBUTES,(void *)&val))) {     printf("    NumAttributes: %i\n",val);fflush(stdout);
         num=val;
@@ -158,13 +149,22 @@ void bml(test_info(char *libpath)) {
           if(bml(get_attribute_info(bmh,i,BM_ATTR_NAME,(void *)&str)))         printf("        Name: \"%s\"\n",str);
           if(bml(get_attribute_info(bmh,i,BM_ATTR_MIN_VALUE,(void *)&mival)) &&
              bml(get_attribute_info(bmh,i,BM_ATTR_MAX_VALUE,(void *)&maval)) &&
-             bml(get_attribute_info(bmh,i,BM_ATTR_DEF_VALUE,(void *)&val)))    printf("        Value: %d .. %d .. %d\n",mival,val,maval);
-          val=bml(get_attribute_value(bm,i);printf("        RealValue: %d\n",val));
+             bml(get_attribute_info(bmh,i,BM_ATTR_DEF_VALUE,(void *)&val))) {
+            printf("        Value: %d .. %d .. %d\n",mival,val,maval);
+            val=bml(get_attribute_value(bm,i);printf("        RealValue: %d\n",val));
+          }
         }
       }
+      bml(free(bm));
 
       puts("  done");
+      okay=1;
+    } else {
+      printf("%s: can't instantiate plugin \"%s\"\n",__FUNCTION__,libpath);
     }
     bml(close(bmh));
+  } else {
+    printf("%s: can't open plugin \"%s\"\n",__FUNCTION__,libpath);
   }
+  return okay;
 }
