@@ -1,7 +1,5 @@
-/* $Id: bmltest_process.c 3724 2011-12-02 17:50:30Z ensonic $
- *
- * Buzz Machine Loader
- * Copyright (C) 2006 Buzztard team <buzztard-devel@lists.sf.net>
+/* Buzz Machine Loader
+ * Copyright (C) 2006 Buzztrax team <buzztrax-devel@buzztrax.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,9 +12,7 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 /*
  * process data with a buzz machine
@@ -24,8 +20,8 @@
  * invoke it e.g. as
  *   LD_LIBRARY_PATH=".:./BuzzMachineLoader/.libs" ./bmltest_process ../machines/elak_svf.dll input.raw output1.raw
  *   LD_LIBRARY_PATH=".:./BuzzMachineLoader/.libs" ./bmltest_process ../../buzzmachines/Elak/SVF/libelak_svf.so input.raw output2.raw
- *   LD_LIBRARY_PATH=".:./BuzzMachineLoader/.libs" ./bmltest_process ~/buzztard/lib/Gear/Effects/Jeskola\ NiNjA\ dElaY.dll input.raw output1.raw
- *   LD_LIBRARY_PATH=".:./BuzzMachineLoader/.libs" ./bmltest_process ~/buzztard/lib/Gear/Jeskola_Ninja.so input.raw output1.raw
+ *   LD_LIBRARY_PATH=".:./BuzzMachineLoader/.libs" ./bmltest_process ~/buzztrax/lib/Gear/Effects/Jeskola\ NiNjA\ dElaY.dll input.raw output1.raw
+ *   LD_LIBRARY_PATH=".:./BuzzMachineLoader/.libs" ./bmltest_process ~/buzztrax/lib/Gear/Jeskola_Ninja.so input.raw output1.raw
  *
  * aplay -fS16_LE -r44100 input.raw
  * aplay -fS16_LE -r44100 output1.raw
@@ -58,17 +54,18 @@
 // like MachineInterface.h::MAX_BUFFER_LENGTH
 #define BUFFER_SIZE 256
 
-#ifdef HAVE_X86
+#ifdef USE_DLLWRAPPER
 #define bml(a) bmlw_ ## a
 #include "bmltest_process.h"
 #undef bml
-#endif  /* HAVE_X86 */
+#endif  /* USE_DLLWRAPPER */
 
 #define bml(a) bmln_ ## a
 #include "bmltest_process.h"
 #undef bml
 
 int main( int argc, char **argv ) {
+  int okay=0;
   setlinebuf(stdout);
   setlinebuf(stderr);
   puts("main beg");
@@ -77,9 +74,9 @@ int main( int argc, char **argv ) {
     char *lib_name;
     int sl;
 
-#ifdef HAVE_X86
+#ifdef USE_DLLWRAPPER
     bmlw_set_master_info(120,4,44100);
-#endif
+#endif  /* USE_DLLWRAPPER */
     bmln_set_master_info(120,4,44100);
     puts("  master info initialized");
 
@@ -87,15 +84,15 @@ int main( int argc, char **argv ) {
       lib_name=argv[1];
       sl=strlen(lib_name);
       if(sl>4) {
-        if(!strcmp(&lib_name[sl-4],".dll")) {
-#ifdef HAVE_X86
-          bmlw_test_process(lib_name,argv[2],argv[3]);
+        if(!strcasecmp(&lib_name[sl-4],".dll")) {
+#ifdef USE_DLLWRAPPER
+          okay=bmlw_test_process(lib_name,argv[2],argv[3]);
 #else
           puts("no dll emulation on non x86 platforms");
-#endif  /* HAVE_X86 */
+#endif  /* USE_DLLWRAPPER */
         }
         else {
-          bmln_test_process(lib_name,argv[2],argv[3]);
+          okay=bmln_test_process(lib_name,argv[2],argv[3]);
         }
       }
     }
@@ -104,5 +101,5 @@ int main( int argc, char **argv ) {
   }
 
   puts("main end");
-  return 0;
+  return okay ? 0 : 1;
 }
